@@ -548,7 +548,7 @@ class JSONRPCClient(object):
             jsonrpc_data = jsonrpc_loads(content, self._version)
         except Exception, e:
             raise JSONRPCParseError("%s" % e)
-        if jsonrpc_data['id'] == self._id:
+        if jsonrpc_data['id'] != self._id:
             raise JSONRPCServerError('JSONRPC request id is `%s`, but response id is `%s`' % (self._id, jsonrpc_data['id']))
         if (jsonrpc_data["error"] != None):
             if jsonrpc_data["error"]["code"] in jsonrpc_error_map:
